@@ -16,9 +16,11 @@ try:
     dotenv_result = load_dotenv(dotenv_path=dotenv_path)
     print('dotenv[celery] configuration %s from "%s"' % ('loaded' if dotenv_result else 'not loaded', dotenv_path))
 except BaseException as e:
+    logging.error('dotenv[celery] configuration could not loaded')
     logging.exception(e)
-
-os.environ.setdefault("DJANGO_CONFIGURATION", os.getenv('KRYNEGGER_CONFIGURATION').capitalize())
+    os.environ.setdefault("KRYNEGGER_CONFIGURATION", "development")
+finally:
+    os.environ.setdefault("DJANGO_CONFIGURATION", os.getenv('KRYNEGGER_CONFIGURATION').capitalize())
 
 try:
     import configurations
