@@ -93,7 +93,7 @@ class CeleryConfigurationMixin(object):
     }
 
 
-class BasicConfiguration(Configuration, SentryConfigurationMixin, MailConfigurationMixin, CeleryConfigurationMixin):
+class BasicConfiguration(SentryConfigurationMixin, MailConfigurationMixin, CeleryConfigurationMixin, Configuration):
     """
     Basic CRM configuration, which satisfying the [ISO-27001](https://google.com), [ISO-270018](https://google.com),
     [SOC:AICPAA](https://google.com), and  [HIPAA](https://google.com) standards.
@@ -588,7 +588,7 @@ class Staging(BasicConfiguration):
 #                     "token_chars": ["letter", "digit"]
 #                     "max_gram": 12,
 
-class Production(Staging):
+class Production(BasicConfiguration):
     """
     Production CRM configuration, secure and rmd.
     """
